==> kdevelop-4.5.80.tar.xz: kdevelop-4.5.80/projectbuilders/ninjabuilder/kdevninja.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=Ninja Project Builder
Name[cs]=Překladač projektů Ninja
Name[de]=Ninja-Projekterstellung
Name[es]=Constructor de proyectos Ninja
Name[fi]=Ninja-projektikäännin
Name[gl]=Construtor de proxectos Ninja
Name[hu]=Ninja projektfordító
Name[nl]=Ninja-project bouwprogramma
Name[pt]=Construtor de Projectos Ninja
Name[pt_BR]=Compilador de projetos Ninja
Name[sl]=Izgrajevalnik projektov Ninja
Name[sv]=Ninja projektbyggverktyg
Name[uk]=Збирач проектів Ninja
Name[x-test]=xxNinja Project Builderxx
Name[zh_TW]=Ninja 專案編譯器
GenericName=Project Builder
GenericName[bs]=Graditelj projekta
GenericName[ca]=Constructor de projectes
GenericName[ca@valencia]=Constructor de projectes
GenericName[cs]=Překladač projektů
GenericName[da]=Bygning af projekter
GenericName[de]=Projektersteller
GenericName[el]=Κατασκευαστής έργου
GenericName[en_GB]=Project Builder
GenericName[es]=Constructor de proyectos
GenericName[et]=Projektiehitaja
GenericName[fi]=Projektikäännin
GenericName[fr]=Constructeur de projets
GenericName[ga]=Tógálaí Tionscadal
GenericName[gl]=Construtor de proxectos
GenericName[hu]=Projektfordító
GenericName[it]=Compilatore progetto
GenericName[ja]=プロジェクトビルダー
GenericName[kk]=Жоба құрастырғышы
GenericName[km]=កម្មវិធី​ស្ថាបនា​គម្រោង
GenericName[nb]=Prosjektbygger
GenericName[nds]=Projektbuumoduul
GenericName[nl]=Projectbouwer
GenericName[pl]=Budowanie projektu
GenericName[pt]=Construtor de Projectos
GenericName[pt_BR]=Compilador de projetos
GenericName[ru]=Сборщик проектов
GenericName[sk]=Prekladač projektov
GenericName[sl]=Izgrajevalnik projektov
GenericName[sv]=Projektbyggverktyg
GenericName[tr]=Proje Oluşturucu
GenericName[ug]=قۇرۇلۇش ياسىغۇچ
GenericName[uk]=Збирання проектів
GenericName[x-test]=xxProject Builderxx
GenericName[zh_CN]=工程构建器
GenericName[zh_TW]=專案編譯器
Comment=KDevelop Ninja Builder
Comment[de]=KDevelop-Ninja-Erstellung
Comment[es]=Constructor Ninja para KDevelop
Comment[fi]=KDevelop Ninja-käännin
Comment[gl]=Construtor Ninja para o KDevelop
Comment[hu]=KDevelop Ninja fordító
Comment[nl]=KDevelop Ninja-bouwprogramma
Comment[pt]=Construtor Ninja do KDevelop
Comment[pt_BR]=Compilador Ninja do KDevelop
Comment[sl]=Izgrajevalnik Ninja za KDevelop
Comment[sv]=KDevelop byggverktyg för Ninja
Comment[uk]=Збирач Ninja для KDevelop
Comment[x-test]=xxKDevelop Ninja Builderxx
Comment[zh_TW]=KDevelop Ninja 建立器
Icon=gear
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevninja
X-KDE-PluginInfo-Name=KDevNinjaBuilder
X-KDE-PluginInfo-Category=Project Management
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Project
X-KDevelop-Interfaces=org.kdevelop.IProjectBuilder
X-KDevelop-IRequired=org.kdevelop.IOutputView
X-KDevelop-Mode=NoGUI

==> kdevelop-4.5.90.tar.xz: kdevelop-4.5.90/projectbuilders/ninjabuilder/kdevninja.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=Ninja Project Builder
Name[bs]=Graditelj Ninja projekta
Name[ca]=Constructor de projectes Ninja
Name[cs]=Překladač projektů Ninja
Name[de]=Ninja-Projekterstellung
Name[es]=Constructor de proyectos Ninja
Name[fi]=Ninja-projektikäännin
Name[gl]=Construtor de proxectos Ninja
Name[hu]=Ninja projektfordító
Name[it]=Compilatore progetto Ninja
Name[kk]=Ninja жоба құрастырғышы
Name[nl]=Ninja-project bouwprogramma
Name[pt]=Construtor de Projectos Ninja
Name[pt_BR]=Compilador de projetos Ninja
Name[sk]=Zostavovač projektov Ninja
Name[sl]=Izgrajevalnik projektov Ninja
Name[sv]=Ninja projektbyggverktyg
Name[uk]=Збирач проектів Ninja
Name[x-test]=xxNinja Project Builderxx
Name[zh_TW]=Ninja 專案編譯器
GenericName=Project Builder
GenericName[bs]=Graditelj projekta
GenericName[ca]=Constructor de projectes
GenericName[ca@valencia]=Constructor de projectes
GenericName[cs]=Překladač projektů
GenericName[da]=Bygning af projekter
GenericName[de]=Projektersteller
GenericName[el]=Κατασκευαστής έργου
GenericName[en_GB]=Project Builder
GenericName[es]=Constructor de proyectos
GenericName[et]=Projektiehitaja
GenericName[fi]=Projektikäännin
GenericName[fr]=Constructeur de projets
GenericName[ga]=Tógálaí Tionscadal
GenericName[gl]=Construtor de proxectos
GenericName[hu]=Projektfordító
GenericName[it]=Compilatore progetto
GenericName[ja]=プロジェクトビルダー
GenericName[kk]=Жоба құрастырғышы
GenericName[km]=កម្មវិធី​ស្ថាបនា​គម្រោង
GenericName[nb]=Prosjektbygger
GenericName[nds]=Projektbuumoduul
GenericName[nl]=Projectbouwer
GenericName[pl]=Budowanie projektu
GenericName[pt]=Construtor de Projectos
GenericName[pt_BR]=Compilador de projetos
GenericName[ru]=Сборщик проектов
GenericName[sk]=Prekladač projektov
GenericName[sl]=Izgrajevalnik projektov
GenericName[sv]=Projektbyggverktyg
GenericName[tr]=Proje Oluşturucu
GenericName[ug]=قۇرۇلۇش ياسىغۇچ
GenericName[uk]=Збирання проектів
GenericName[x-test]=xxProject Builderxx
GenericName[zh_CN]=工程构建器
GenericName[zh_TW]=專案編譯器
Comment=KDevelop Ninja Builder
Comment[bs]=KDevelop Ninja izgraditelj
Comment[ca]=Constructor Ninja del KDevelop
Comment[de]=KDevelop-Ninja-Erstellung
Comment[es]=Constructor Ninja para KDevelop
Comment[fi]=KDevelop Ninja-käännin
Comment[gl]=Construtor Ninja para o KDevelop
Comment[hu]=KDevelop Ninja fordító
Comment[it]=Compilatore Ninja di KDevelop
Comment[kk]=KDevelop-тың Ninja құрастырғышы
Comment[nl]=KDevelop Ninja-bouwprogramma
Comment[pt]=Construtor Ninja do KDevelop
Comment[pt_BR]=Compilador Ninja do KDevelop
Comment[sk]=Zostavovač KDevelop Ninja
Comment[sl]=Izgrajevalnik Ninja za KDevelop
Comment[sv]=KDevelop byggverktyg för Ninja
Comment[uk]=Збирач Ninja для KDevelop
Comment[x-test]=xxKDevelop Ninja Builderxx
Comment[zh_TW]=KDevelop Ninja 建立器
Icon=gear
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevninja
X-KDE-PluginInfo-Name=KDevNinjaBuilder
X-KDE-PluginInfo-Category=Project Management
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Project
X-KDevelop-Interfaces=org.kdevelop.IProjectBuilder
X-KDevelop-IRequired=org.kdevelop.IOutputView
X-KDevelop-Mode=NoGUI
